@@ -56,7 +56,7 @@ double reflect(double x, double a, double b);
 #define rndexp(mean) (-(mean)*log(rndu()))
 double rnduM0V1 (void);
 double rndNormal(void);
-int rndNp(double x[], int n, int p, double mx[], double vx[], int isvroot);
+int rndNp(double x[], int n, int p, double mx[], double cholesky[]);
 int rndBinomial(int n, double p);
 double rndBox(void);
 double rndAirplane(void);
@@ -207,7 +207,7 @@ void strcase (char *str, int direction);
 void zerror(const char* format, ...);
 int  indexing(double x[], int n, int index[], int descending, int space[]);
 int binarysearch (const void *key, const void *base, size_t n, size_t size, int(*compare)(const void *, const void *), int *found);
-FILE *zopen(char *filename, char *mode);
+FILE *zfopen(char *filename, char *mode);
 int  appendfile(FILE*fout, char*filename);
 
 int zero (double x[], int n);
@@ -369,10 +369,6 @@ int UseLocus (int locus, int copyconP, int setmodel, int setSeqName);
 int GetGtree(int locus);
 int printGtree(int printBlength);
 
-void copySptree(void);
-void printSptree(void);
-
-
 enum DataType {BASEseq = 0, CODONseq = 1, AAseq = 2, CODON2AAseq = 3, BINARYseq = 4, BASE5seq = 5};
 enum PrintOptions { PrBranch = 1, PrNodeNum = 2, PrLabel = 4, PrNodeStr = 8, PrAge = 16, PrOmega = 32 };
 
@@ -393,6 +389,6 @@ enum PrintOptions { PrBranch = 1, PrNodeNum = 2, PrLabel = 4, PrNodeStr = 8, PrA
 
 #define PAML_RELEASE      0
 
-#define pamlVerStr "paml version 4.10.7, June 2023"
+#define pamlVerStr "paml version 4.10.10, 29 Jan 2026"
 
 #endif
